Struct SendWrapper
Source pub struct SendWrapper<T> {
inner: ManuallyDrop<T>,
address_space: ManuallyDrop<WeakAddressSpace>,
}
Available on crate feature full and non-crate feature use_std only.
Formats the value using the given formatter.
Read more
Executes the destructor for this type.
Read more
🔬This is a nightly-only experimental API. (pin_ergonomics)
Execute the destructor for this type, but different to
Drop::drop, it requires
self
to be pinned.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.