pub trait SpinlockGuardExt {
// Required method
fn unlock_no_interrupts(this: Self);
}Available on crate feature
full and non-crate feature use_std only.Expand description
Extension functions to SpinlockGuard
Required Methods
Sourcefn unlock_no_interrupts(this: Self)
fn unlock_no_interrupts(this: Self)
Unlock the spinlock without enabling interrupts, regardless of whether interrupts were enabled before the spinlock was locked
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.